@@ -23,6 +23,6 @@ class ServerList(list):
 
         return random.choice(self)
 
-    def markDead(self, server):
+    def mark_dead(self, server):
         self.remove(server)
         self.dead.insert(0, (time.time() + self.retry_time, server))
